<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Bilgi</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Çevirenler</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1 Tarayıcı SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Sürüm: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Taşınabilir Sürüm</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Qt %1 ile derlendi (%2 kullanılarak)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Güncellemeler için web adresini ziyaret edin:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Birçok insan çevirilere katkıda bulundu.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Ayrıca SMPlayerı kendi dilinize çevirmek için yadım edebilirsiniz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>%1 sayfasını ziyaret edip çeviri takımına katılabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Transifex takımındaki çevirmenleri görmek için tıkla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="138"/>
        <source>Home</source>
        <translation>Anasayfa</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="141"/>
        <source>Navigation</source>
        <translation>Gezinti</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="149"/>
        <source>Zoom +</source>
        <translation>Yakınlaştır +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="153"/>
        <source>Zoom -</source>
        <translation>Uzaklaştır -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="157"/>
        <source>&amp;Quit</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Gezinti</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="172"/>
        <source>&amp;View</source>
        <translation>&amp;Gösterim</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="173"/>
        <source>Toolbar</source>
        <translation>Araç çubuğu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="177"/>
        <source>Statusbar</source>
        <translation>Durum çubuğu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="198"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>YouTube oynatma desteğini &amp;güncelleyin</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="200"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>YouTube oynatma desteğini &amp;Yükleyin / Güncelleyin</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="206"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;SMPlayer Hakkında</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="331"/>
        <source>Download video using an external service</source>
        <translation>Videoyu harici servisleri kullanarak indir</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="332"/>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="578"/>
        <source>No video found</source>
        <translation>Video bulunamadı</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Video bağlantısı bulunamadı</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="610"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="611"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer için YouTube%1 Tarayıcı</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="317"/>
        <source>Loading... %1%</source>
        <translation>Yükleniyor.. %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>İndiriyor...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>%1 ile bağlantı kuruluyor</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>YouTube kodu başarıyla yüklendi.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>Kurulu sürüm: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>%1 kaydetmek olanaksız.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Dosya indirilirken bir hata oluştu:&lt;br&gt;%1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation>%1 youtube-dl ile iletişim kuramadı. Ya kurulu değil ya da düzgün çalışmıyor.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Bu videonun URL&apos;sini bulmak mümkün değil.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation>Belki youtube-dl&apos;yi güncellemeniz gerekir.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation>YouTube videolarını oynatmak için %1&apos;in youtube-dl adlı harici bir uygulamaya ihtiyacı var.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation>Bu bileşenin sık sık güncellenmesi gerekiyor.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation>Yalnızca SMPlayer&apos;ı yeniden yükleyerek güncelleyebilirsiniz. Yükleyici en son sürümü indirip kuracaktır.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation>Youtube desteğini yükle / güncelle</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="232"/>
        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
        <translation>YouTube videolarını oynatmak için %1&apos;in harici bir uygulamanın yardımına ihtiyacı var.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="233"/>
        <source>%1 can download and install this application for you.</source>
        <translation>%1 bu uygulamayı sizin için indirip kurabilir.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="234"/>
        <source>It will be downloaded from the official website and installed as %1.</source>
        <translation>Resmi web sitesinden indirilecek ve %1 olarak yüklenecektir.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="235"/>
        <source>Would you like to proceed?</source>
        <translation>Devam etmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="239"/>
        <location filename="../codedownloader.cpp" line="242"/>
        <source>Install YouTube support?</source>
        <translation>Youtube desteği yüklensin mi?</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Genel</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation>E&amp;kle...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="178"/>
        <source>&amp;Players</source>
        <translation>&amp;Oynatıcılar</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="226"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Oynatma</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Tercih edilen &amp;kalite:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation>Siteler</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation>&amp;Site:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation>Düzenl&amp;e...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation>Si&amp;l...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="152"/>
        <source>YouTube support application</source>
        <translation>YouTube destek uygulaması</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="237"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="261"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="274"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Önceden ayarlı oynatıcı ekle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="310"/>
        <source>&amp;Interface</source>
        <translation>&amp;Arayüz</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="318"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stil:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="354"/>
        <source>Font:</source>
        <translation>Yazı tipi:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="368"/>
        <source>C&amp;hange...</source>
        <translation>De&amp;ğiştir...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Videoyu &amp;harici servisleri kullanarak indir</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="202"/>
        <source>Down</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="82"/>
        <source>Default</source>
        <translation>Öntanımlı</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="460"/>
        <source>yt-dlp (based on youtube-dl with improvements)</source>
        <translation>yt-dlp (iyileştirmelerle birlikte youtube-dl&apos;ye dayalı)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="478"/>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Dosya veya klasör seçmek için tıklayın</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>&amp;YouTube&apos;da Aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Bağlantıyı kaydet...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>&amp;Bağlantıyı panoya kopyala</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Bu pencerede linki aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>Metni panoya &amp;kopyala</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Bağlantıyı &amp;yeni pencerede aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Birlikte yürüt</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>Şununla &amp;ses çalın</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>%1 ile oynat</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="145"/>
        <source>Play &amp;audio with %1</source>
        <translation>%1 ile &amp;ses çalma</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="154"/>
        <source>Play video with a &amp;web browser</source>
        <translation>&amp;Tarayıcı ile video oynatma</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Oynatıcıyı düzenle</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;İsim:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Çalıştırılabilir:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametreler:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Bu oynatıcı video sitelerini destekler</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Bu oynatıcı çevrimiçi TV oynatabilir</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Tercih edilen &amp;kalite:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>&amp;Menüye ekle</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video ve ses</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../version.cpp" line="48"/>
        <source>%1 (revision %2) %3</source>
        <translation>%1 (gözden geçirme %2) %3</translation>
    </message>
    <message>
        <location filename="../version.cpp" line="50"/>
        <source>%1 (revision %2)</source>
        <translation>%1 (gözden geçirme %2)</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation>Siteyi Düzenle</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Ad:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation>&amp;Ana sayfa URL&apos;si:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation>&amp;Arama URL&apos;si:</translation>
    </message>
</context>
</TS>